package com.hydrogen.brandManager.config;

import feign.Feign;
import okhttp3.ConnectionPool;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.cloud.openfeign.FeignAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.concurrent.TimeUnit;

/**
 * @ClassName OpenFeignInterfaceConfiguration
 * @Description OpenFeignConfig 配置管理
 * @Author chaixueteng
 * @Date 2020/3/10 9:46
 */
@Configuration
@ConditionalOnClass(Feign.class)
@AutoConfigureBefore(FeignAutoConfiguration.class)
public class FeignOkHttpConfig {


    @Bean
    public okhttp3.OkHttpClient okHttpClient(){
        return new okhttp3.OkHttpClient.Builder()
                //设置连接超时
                .connectTimeout(15, TimeUnit.SECONDS)
                //设置读超时
                .readTimeout(15, TimeUnit.SECONDS)
                //是否自动重连
                .retryOnConnectionFailure(true)
                // 最大连接数、连接存活时间、存活时间单位（分钟）
                .connectionPool(new ConnectionPool(200, 5, TimeUnit.MINUTES))
                //构建OkHttpClient对象
                .build();
    }
}
