package com.hydrogen.brandManager.filter;

import com.alibaba.fastjson.JSONObject;
import com.hydrogen.mbg.utils.JwtTokenUtil;
import com.hydrogen.mbg.utils.RedisUtil;
import com.hydrogen.mbg.vo.DrhtResult;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * 登陆拦截器
 */
@Slf4j
public class AuthenticationInterceptor implements HandlerInterceptor {

    @Resource
    JwtTokenUtil jwtTokenUtil;
    @Resource
    RedisUtil redisUtil;
    /**
     * 请求前置校验
     * @param request current HTTP request
     * @param response current HTTP response
     * @param handler chosen handler to execute, for type and/or instance evaluation
     * @return
     * @throws Exception
     */
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        if ("OPTIONS".equals(request.getMethod())) {//这里通过判断请求的方法，判断此次是否是预检请求，如果是，标示，允许跨域；预检后，正式请求，这个方法参数就是我们设置的post了
            response.setHeader("Access-Control-Allow-Methods", "POST, GET, DELETE, OPTIONS, DELETE");//当判定为预检请求后，设定允许请求的方法
            response.setHeader("Access-Control-Allow-Headers", "Content-Type, x-requested-with, Token"); //当判定为预检请求后，设定允许请求的头部类型
            response.addHeader("Access-Control-Max-Age", "1");
            return true;
        }

        // 从 http 请求头中取出 token
        String authorizationToken = request.getHeader("Authorization");
        if (!StringUtils.isEmpty(authorizationToken)) {
            //判断token是否有效
            return jwtTokenUtil.validateToken(authorizationToken);
        }

        writeResponse(response);
        return true;
    }


    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) {
//        String token = request.getHeader("token");
//        userDao.refreshToken(token);
    }

    /**
     * 写入响应
     *
     * @param resp 响应结果
     * @throws IOException
     */
    private void writeResponse(HttpServletResponse resp) throws IOException {
        DrhtResult<Object> fail = DrhtResult.build(1000, "请重新登陆");
        resp.setCharacterEncoding("utf-8");
        resp.setContentType("text/javascript");
        PrintWriter writer = resp.getWriter();
        writer.write(JSONObject.toJSON(fail).toString());
        writer.flush();
        writer.close();
    }
}
