package com.hydrogen.brandManager.filter;

import com.hydrogen.mbg.vo.DrhtResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.validation.ObjectError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;

/**
 * 全局Controller参数校验异常处理
 *
 * @author linyx
 * @Date 2019/7/16
 */
@ControllerAdvice
@Slf4j
public class GlobalParameterValidationHandler {
    @ExceptionHandler(MethodArgumentNotValidException.class)
    @ResponseBody
    public DrhtResult exception(MethodArgumentNotValidException e, HttpServletRequest request) {
        StringBuilder result = new StringBuilder();
        BindingResult bindingResult = e.getBindingResult();
        log.error("请求[ {} ] {} 的参数校验发生错误", request.getMethod(), request.getRequestURL());
        for (ObjectError objectError : bindingResult.getAllErrors()) {
            FieldError fieldError = (FieldError) objectError;
            log.error("参数 {} = {} 校验错误：{}", fieldError.getField(), fieldError.getRejectedValue(), fieldError.getDefaultMessage());
            result.append(fieldError.getDefaultMessage());
            result.append(";");
        }
        return DrhtResult.build(400, result.toString());
    }
}